tisdb.errors module — tisdb 0.0.1.dev0 documentation

# tisdb.errors module

exception `tisdb.errors.` `BaseError`(message='', subcode=10501, status='TISDB Error', *args, **kwargs)

  Bases: `Exception`

  Raised when a error occur.

  Args:

    Exception ([type]): [description]

  `STATUS` = 'TISDB Error'
  `SUBCODE` = 10501

class `tisdb.errors.` `BaseInfo`(message='', subcode=10200, status='ok', **kwargs)

  Bases: `object`

  Returning result info

  Args:

    object ([type]): [description]

  `STATUS`: str = 'ok'
  `SUBCODE`: int = 10200

exception `tisdb.errors.` `FakeError`(message='', subcode=10501, status='TISDB Error', *args, **kwargs)

  Bases: `tisdb.errors.BaseError`

  Fake error for some situation to step in error handler

  `STATUS` = 'TISDB Fake Error'
  `SUBCODE` = 10209

exception `tisdb.errors.` `ParamError`(message='', subcode=10501, status='TISDB Error', *args, **kwargs)

  Bases: `tisdb.errors.BaseError`

  Params error

  `STATUS` = 'TISDB Invalid Parameter Error'
  `SUBCODE` = 10422